==> hboard-1.0-rc1.tar.gz: hboard/install_2.php <==
<?php

/* EtchiBoard Version 1.0
     install_2.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

if(file_exists("dbconn.php")) {
echo "<html>\n<body>\n\n"
    ."<script language=\"JavaScript\" type=\"\">\n"
    ."alert(\"̹ ġ Ϸ Դϴ.\\nٽ ġϽ÷ dbconn.php  Ͻ , ٽ õϼ.\");\n"
    ."</script>\n\n</body>\n</html>";
}

else {

$mysql_connect = mysql_connect($mysql_hostname, $mysql_user, $mysql_password); // ϴ ..

 if(!$mysql_connect) {
 echo "<br><br><table align=\"center\" border=\"1\" cellspacing=\"0\" width=\"320\" bordercolordark=\"white\" bordercolorlight=\"black\">\n"
     ."<tr>\n<td width=\"310\" height=\"80\">\n"
     ."<p align=\"center\"><br><span style=\"font-size:9pt;\"><b>MySQL Database Error</b><br>\n"
     ."MySQL    ϴ."
	 ."<br><br><a href=\"javascript:history.back(1)\"><img border=0 src=\"img/install_ok.jpg\" alt=\"Ȯ\"></a><br><br></span></p>\n"
     ."</td>\n</tr>\n</table>";
 }

 else if(!mysql_select_db($mysql_db)) {
 echo "<br><br><table align=\"center\" border=\"1\" cellspacing=\"0\" width=\"320\" bordercolordark=\"white\" bordercolorlight=\"black\">\n"
     ."<tr>\n<td width=\"310\" height=\"80\">\n"
     ."<p align=\"center\"><br><span style=\"font-size:9pt;\"><b>MySQL Database Error</b><br>\n"
     ."MySQL DB   ϴ."
	 ."<br><br><a href=\"javascript:history.back(1)\"><img border=0 src=\"img/install_ok.jpg\" alt=\"Ȯ\"></a><br><br></span></p>\n"
     ."</td>\n</tr>\n</table>";
  mysql_close($mysql_connect);
 }

 else {
// db 
mysql_select_db($mysql_db);

/* ̺  */
mysql_query("create table hboard_db_admin(passwd varchar(30), skin varchar(100), app int, fileup_max int, html_tag char(1), include_top varchar(255), include_bottom varchar(255), title_text varchar(255), bgimage varchar(255), width_max int, lang varchar(50), article_max int)");
mysql_query("create table hboard_db_article(idx int, name varchar(30), email varchar(100), home varchar(255), ipaddr varchar(50), passwd varchar(30), date varchar(50), cfile varchar(50), subject varchar(255), ment text, deleted char(1), reply int(11), agent varchar(255))");
mysql_query("CREATE TABLE hboard_db_comment (idx int, article int, name varchar(30), email varchar(100), home varchar(255), icon varchar(255), ipaddr varchar(50), passwd varchar(30), date varchar(50), ment text, deleted char(1), agent varchar(255))");
mysql_query("alter table hboard_db_article add index(idx)");
mysql_query("alter table hboard_db_comment add index(article)");

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<meta http-equiv="content-type" content="text/html; charset=ks_c_5601-1987">
<title>EtchiBoard Installation Wizard</title>
</head>

<body bgcolor="white" text="black" link="blue" vlink="purple" alink="red">

<script language="JavaScript" type="">
function checkvalue() {
		if(document.pass.admin_passwd.value == "") {
			alert("йȣ Էϼ.");
			document.pass.admin_passwd.focus();
		}

		else if(document.pass.admin_passwd_confirm.value == "") {
			alert("йȣ Ȯ Էϼ.");
			document.pass.admin_passwd_confirm.focus();
		}

		else if(document.pass.admin_passwd.value != document.pass.admin_passwd_confirm.value) {
			alert("Էµ йȣ   ġ ʽϴ.");
		}

		else{
			document.pass.submit();
	}
}

function reset_value() {
   document.pass.admin_passwd.value = "";
   document.pass.admin_passwd_confirm.value = "";

}
</script>

<table align="center" width="656" cellpadding="0" cellspacing="0">
    <tr>
        <td width="381" height="156">
            <table cellpadding="0" cellspacing="0" width="100%">
                <tr>
                    <td width="100%" bgcolor="#D7D7D7" valign="top" style="padding-top:15; padding-right:0; padding-bottom:0; padding-left:15;" height="160" background="img/installer_capt_bg.jpg">
                        <p><b><font face="Tahoma">Enter Administrator Password:<br></font></b><font face="Tahoma"><span style="font-size:9pt;"> <br>Խ 
                          ʿ  йȣ Է ּ.<br>( 
                        йȣ  ڸ , Խù <br> Ȥ 
                          ˴ϴ.)<br><br>  -  ܰ踦 ġ ʰ Խǿ  ,<br>
						Խ  ۵ ʽϴ.</span></font></p>
                    </td>
                </tr>
            </table>
        </td>
        <td width="259" height="430" rowspan="3">
            <table cellpadding="0" cellspacing="0">
                <tr>
                    <td width="256">
                        <p><img src="img/install_char.jpg" width="279" height="480" border="0" alt="install_char.jpg"></p>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
    <tr>
        <td width="381" height="233">
          <form name="pass" method="post" action="install_3.php">

    <input type="hidden" name="mysql_hostname" value="<?=$mysql_hostname?>">
    <input type="hidden" name="mysql_user" value="<?=$mysql_user?>">
    <input type="hidden" name="mysql_db" value="<?=$mysql_db?>">
    <input type="hidden" name="mysql_password" value="<?=$mysql_password?>">

			<table align="center" cellpadding="0" cellspacing="0" width="295">
                <tr>
                    <td width="295" height="20" bgcolor="#F4F4F4" colspan="2">
                        <p><span style="font-size:9pt;">&nbsp; йȣ</span></p>
                    </td>
                </tr>
                <tr>
                    <td width="115" height="15">
                        <p align="center"><span style="font-size:9pt;">&nbsp;</span></p>
                    </td>
                    <td width="180" height="15">
                        <p><span style="font-size:9pt;">&nbsp;</span></p>
                    </td>
                </tr>
                <tr>
                    <td width="115" height="25">
                        <p align="center"><span style="font-size:9pt;">йȣ</span></p>
                    </td>
                    <td width="180" height="25">
                        <p><span style="font-size:9pt;">&nbsp;<input type="password" name="admin_passwd"></span></p>
                    </td>
                </tr>
                <tr>
                    <td width="115" height="25">
                        <p align="center"><span style="font-size:9pt;">ٽ 
                            Է</span></p>
                    </td>
                    <td width="180" height="25">
                        <p><span style="font-size:9pt;">&nbsp;<input type="password" name="admin_passwd_confirm"></span></p>
                    </td>
                </tr>
            </table>
            <p align="center"><span style="font-size:9pt;"><a href="javascript:checkvalue();"><img src="img/install_ok.jpg" width="85" height="35" border="0" alt="Ȯ"></a> 
                <a href="javascript:reset_value();"><img src="img/install_reset.jpg" width="85" height="35" border="0" alt="ٽ ۼ"></a></span></p>
            </form>
        </td>
    </tr>
    <tr>
        <td width="381" height="22">
            <p align="right"><span style="font-size:8pt;"><font face="Tahoma" color="#999999">EtchiBoard 
            Gallery System: by EtchiBBS Project.<br> http://etchibbs.kldp.net</font></span></p>
        </td>
    </tr>
</table>
</body>

</html>
<?php
mysql_close($mysql_connect);
 }
}
?>

==> hboard-1.0.1.tar.gz: hboard/install_2.php <==
<?php

/* EtchiBoard Version 1.0
     install_2.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

if(file_exists("dbconn.php")) {
echo "<html>\n<body>\n\n"
    ."<script language=\"JavaScript\" type=\"\">\n"
    ."alert(\"̹ ġ Ϸ Դϴ.\\nٽ ġϽ÷ dbconn.php  Ͻ , ٽ õϼ.\");\n"
    ."</script>\n\n</body>\n</html>";
}

else {

$mysql_connect = mysql_connect($mysql_hostname, $mysql_user, $mysql_password); // ϴ ..

 if(!$mysql_connect) {
 echo "<br><br><table align=\"center\" border=\"1\" cellspacing=\"0\" width=\"320\" bordercolordark=\"white\" bordercolorlight=\"black\">\n"
     ."<tr>\n<td width=\"310\" height=\"80\">\n"
     ."<p align=\"center\"><br><span style=\"font-size:9pt;\"><b>MySQL Database Error</b><br>\n"
     ."MySQL    ϴ."
	 ."<br><br><a href=\"javascript:history.back(1)\"><img border=0 src=\"img/install_ok.jpg\" alt=\"Ȯ\"></a><br><br></span></p>\n"
     ."</td>\n</tr>\n</table>";
 }

 else if(!mysql_select_db($mysql_db)) {
 echo "<br><br><table align=\"center\" border=\"1\" cellspacing=\"0\" width=\"320\" bordercolordark=\"white\" bordercolorlight=\"black\">\n"
     ."<tr>\n<td width=\"310\" height=\"80\">\n"
     ."<p align=\"center\"><br><span style=\"font-size:9pt;\"><b>MySQL Database Error</b><br>\n"
     ."MySQL DB   ϴ."
	 ."<br><br><a href=\"javascript:history.back(1)\"><img border=0 src=\"img/install_ok.jpg\" alt=\"Ȯ\"></a><br><br></span></p>\n"
     ."</td>\n</tr>\n</table>";
  mysql_close($mysql_connect);
 }

 else {
// db 
mysql_select_db($mysql_db);

/* Խ ̹ ġǾ ִ ;  Ѹ x */
if(mysql_query("select count(*) from hboard_db_admin", $mysql_connect)) {
 echo "<br><br><table align=\"center\" border=\"1\" cellspacing=\"0\" width=\"320\" bordercolordark=\"white\" bordercolorlight=\"black\">\n"
     ."<tr>\n<td width=\"310\" height=\"80\">\n"
     ."<p align=\"center\"><br><span style=\"font-size:9pt;\"><b>MySQL Table Error</b><br>\n"
     ."̹  ̺ ͺ̽ մϴ."
	 ."<br><br><a href=\"javascript:history.back(1)\"><img border=0 src=\"img/install_ok.jpg\" alt=\"Ȯ\"></a><br><br></span></p>\n"
     ."</td>\n</tr>\n</table>";
  mysql_close($mysql_connect);
  die;
}

/* ƴ϶; ̺  */
mysql_query("create table hboard_db_admin(passwd varchar(30), skin varchar(100), app int, fileup_max int, html_tag char(1), include_top varchar(255), include_bottom varchar(255), title_text text, bgimage varchar(255), width_max int, lang varchar(50), article_max int, titlebar varchar(255), autolink char(1), backdrum char(1))");
mysql_query("create table hboard_db_article(idx int, name varchar(30), email varchar(100), home varchar(255), ipaddr varchar(50), passwd varchar(30), date varchar(50), cfile varchar(50), subject varchar(255), ment text, deleted char(1), reply int(11), agent varchar(255), md5 varchar(32))");
mysql_query("CREATE TABLE hboard_db_comment (idx int, article int, name varchar(30), email varchar(100), home varchar(255), icon varchar(255), ipaddr varchar(50), passwd varchar(30), date varchar(50), ment text, deleted char(1), agent varchar(255))");
mysql_query("alter table hboard_db_article add index(idx)");
mysql_query("alter table hboard_db_comment add index(article)");

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<meta http-equiv="content-type" content="text/html; charset=ks_c_5601-1987">
<title>EtchiBoard Installation Wizard</title>
</head>

<body bgcolor="white" text="black" link="blue" vlink="purple" alink="red">

<script language="JavaScript" type="">
function checkvalue() {
		if(document.pass.admin_passwd.value == "") {
			alert("йȣ Էϼ.");
			document.pass.admin_passwd.focus();
		}

		else if(document.pass.admin_passwd_confirm.value == "") {
			alert("йȣ Ȯ Էϼ.");
			document.pass.admin_passwd_confirm.focus();
		}

		else if(document.pass.admin_passwd.value != document.pass.admin_passwd_confirm.value) {
			alert("Էµ йȣ   ġ ʽϴ.");
		}

		else{
			document.pass.submit();
	}
}

function reset_value() {
   document.pass.admin_passwd.value = "";
   document.pass.admin_passwd_confirm.value = "";

}
</script>

<table align="center" width="656" cellpadding="0" cellspacing="0">
    <tr>
        <td width="381" height="156">
            <table cellpadding="0" cellspacing="0" width="100%">
                <tr>
                    <td width="100%" bgcolor="#D7D7D7" valign="top" style="padding-top:15; padding-right:0; padding-bottom:0; padding-left:15;" height="160" background="img/installer_capt_bg.jpg">
                        <p><b><font face="Tahoma">Enter Administrator Password:<br></font></b><font face="Tahoma"><span style="font-size:9pt;"> <br>Խ 
                          ʿ  йȣ Է ּ.<br>( 
                        йȣ  ڸ , Խù <br> Ȥ 
                          ˴ϴ.)<br><br>  -  ܰ踦 ġ ʰ Խǿ  ,<br>
						Խ  ۵ ʽϴ.</span></font></p>
                    </td>
                </tr>
            </table>
        </td>
        <td width="259" height="430" rowspan="3">
            <table cellpadding="0" cellspacing="0">
                <tr>
                    <td width="256">
                        <p><img src="img/install_char.jpg" width="279" height="480" border="0" alt="install_char.jpg"></p>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
    <tr>
        <td width="381" height="233">
          <form name="pass" method="post" action="install_3.php">

    <input type="hidden" name="mysql_hostname" value="<?php echo $mysql_hostname?>">
    <input type="hidden" name="mysql_user" value="<?php echo $mysql_user?>">
    <input type="hidden" name="mysql_db" value="<?php echo $mysql_db?>">
    <input type="hidden" name="mysql_password" value="<?php echo $mysql_password?>">

			<table align="center" cellpadding="0" cellspacing="0" width="295">
                <tr>
                    <td width="295" height="20" bgcolor="#F4F4F4" colspan="2">
                        <p><span style="font-size:9pt;">&nbsp; йȣ</span></p>
                    </td>
                </tr>
                <tr>
                    <td width="115" height="15">
                        <p align="center"><span style="font-size:9pt;">&nbsp;</span></p>
                    </td>
                    <td width="180" height="15">
                        <p><span style="font-size:9pt;">&nbsp;</span></p>
                    </td>
                </tr>
                <tr>
                    <td width="115" height="25">
                        <p align="center"><span style="font-size:9pt;">йȣ</span></p>
                    </td>
                    <td width="180" height="25">
                        <p><span style="font-size:9pt;">&nbsp;<input type="password" name="admin_passwd"></span></p>
                    </td>
                </tr>
                <tr>
                    <td width="115" height="25">
                        <p align="center"><span style="font-size:9pt;">ٽ 
                            Է</span></p>
                    </td>
                    <td width="180" height="25">
                        <p><span style="font-size:9pt;">&nbsp;<input type="password" name="admin_passwd_confirm"></span></p>
                    </td>
                </tr>
            </table>
            <p align="center"><span style="font-size:9pt;"><a href="javascript:checkvalue();"><img src="img/install_ok.jpg" width="85" height="35" border="0" alt="Ȯ"></a> 
                <a href="javascript:reset_value();"><img src="img/install_reset.jpg" width="85" height="35" border="0" alt="ٽ ۼ"></a></span></p>
            </form>
        </td>
    </tr>
    <tr>
        <td width="381" height="22">
            <p align="right"><span style="font-size:8pt;"><font face="Tahoma" color="#999999">EtchiBoard 
            Gallery System: by EtchiBBS Project.<br> http://etchibbs.kldp.net</font></span></p>
        </td>
    </tr>
</table>
</body>

</html>
<?php
mysql_close($mysql_connect);
 }
}
?>
